######################################
Spectrograms (:mod:`gwpy.spectrogram`)
######################################

.. automodule:: gwpy.spectrogram

.. seealso::

    - **User Guide**: :doc:`/spectrogram/index`
    - **Examples**: :doc:`/examples/spectrogram/index`

.. automodapi:: gwpy.spectrogram
    :include-all-objects:
    :no-heading:
    :no-main-docstr:
